@@ -1,6 +1,6 @@
 /* client.c
  *
- * $Id: client.c,v 1.92 2000/04/21 22:29:33 nisse Exp $ */
+ * $Id: client.c,v 1.93 2000/04/23 17:48:47 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -265,10 +265,10 @@ do_exit_signal(struct channel_request *c,
   UINT32 signal;
   int core;
 
-  UINT8 *msg;
+  const UINT8 *msg;
   UINT32 length;
 
-  UINT8 *language;
+  const UINT8 *language;
   UINT32 language_length;
   
   if (!want_reply
