@@ -1,6 +1,6 @@
 /* connection_commands.c
  *
- * $Id: connection_commands.c,v 1.25 2000/04/21 21:10:09 nisse Exp $
+ * $Id: connection_commands.c,v 1.26 2000/05/06 11:17:31 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -240,8 +240,6 @@ do_line(struct line_handler **h,
 	  werror("Unsupported protocol version: %ps\n",
 		 length, line);
 
-	  /* FIXME: Clean up properly */
-	  KILL(closure);
 	  *h = NULL;
 
 	  EXCEPTION_RAISE(connection->e,
