@@ -1,6 +1,6 @@
 /* keyexchange.c
  *
- * $Id: keyexchange.c,v 1.62 2000/04/23 17:31:00 nisse Exp $ */
+ * $Id: keyexchange.c,v 1.63 2000/05/06 11:17:35 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -168,8 +168,9 @@ initiate_keyexchange(struct ssh_connection *connection,
     }
 }
 
-static int select_algorithm(struct int_list *server_list,
-			    struct int_list *client_list)
+static int
+select_algorithm(struct int_list *server_list,
+		 struct int_list *client_list)
 {
   /* FIXME: This quadratic complexity algorithm should do as long as
    * the lists are short. To avoid DOS-attacks, ther should probably
@@ -190,7 +191,8 @@ static int select_algorithm(struct int_list *server_list,
   return 0;
 }
 
-void disconnect_kex_failed(struct ssh_connection *connection, const char *msg)
+void
+disconnect_kex_failed(struct ssh_connection *connection, const char *msg)
 {
   EXCEPTION_RAISE
     (connection->e,
