@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: publickey_crypto.h,v 1.30 2000/04/19 00:44:05 nisse Exp $ */
+ * $Id: publickey_crypto.h,v 1.31 2000/04/23 17:48:51 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -93,7 +93,7 @@ struct signature_algorithm *make_dsa_algorithm(struct randomness *random);
 /* Non spki keys */
 struct dsa_verifier *
 make_ssh_dss_verifier(UINT32 public_length,
-		      UINT8 *public);
+		      const UINT8 *public);
 
 struct lsh_string *
 ssh_dss_public_key(struct signer *s);
