@@ -1,6 +1,6 @@
 /* server_keyexchange.c
  *
- * $Id: server_keyexchange.c,v 1.36 1999/12/12 19:34:07 nisse Exp $ */
+ * $Id: server_keyexchange.c,v 1.37 2000/05/06 11:17:40 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -145,11 +145,6 @@ do_init_server_dh(struct keyexchange_algorithm *c,
 
   NEW(dh_server, dh);
 
-  CHECK_TYPE(ssh_connection, connection);
-  
-  /* FIXME: No spki-style signatures for host keys. */
-  assert(hostkey_algorithm_atom == ATOM_SSH_DSS);
-  
   if (!key)
     {
       werror("Keypair for for selected signature-algorithm not found!\n");
