@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.37 2000/04/23 17:48:52 nisse Exp $
+ * $Id: server_session.c,v 1.39 2000/05/06 19:24:15 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -178,6 +178,8 @@ do_eof(struct ssh_channel *channel)
 {
   CAST(server_session, session, channel);
 
+  trace("server_session.c: do_eof()\n");
+
   write_buffer_close(session->in->write_buffer);
 
   if ( (channel->flags & CHANNEL_SENT_EOF)
@@ -185,6 +187,8 @@ do_eof(struct ssh_channel *channel)
     channel_close(channel);
 }
 
+#if 0
+/* Not needed; the channels resource list is taken care of automatically. */
 static void
 do_close(struct ssh_channel *c)
 {
@@ -193,6 +197,7 @@ do_close(struct ssh_channel *c)
   if (session->process)
     KILL_RESOURCE(session->process);
 }
+#endif
 
 struct ssh_channel *
 make_server_session(struct lsh_user *user,
@@ -213,7 +218,9 @@ make_server_session(struct lsh_user *user,
   self->super.rec_max_packet = SSH_MAX_PACKET - SSH_CHANNEL_MAX_PACKET_FUZZ;
   self->super.request_types = request_types;
 
+#if 0
   self->super.close = do_close;
+#endif
   
   self->user = user;
   self->process = NULL;
@@ -368,16 +375,13 @@ static void do_exit_shell(struct exit_callback *c, int signaled,
   struct ssh_channel *channel = &session->super;
   
   CHECK_TYPE(server_session, session);
+
+  trace("server_session.c: do_exit_shell()\n");
   
-  /* FIXME: Should we explicitly mark these files for closing? The
-   * io-backend should notice EOF anyway. And the client should send
-   * EOF when it receives news of the process's death, unless it
-   * really wants to talk to any live children processes. */
-#if 0
-  close_fd(&session->in->super, 0);
-  close_fd(session->out);
-  close_fd(session->err);
-#endif
+  /* NOTE: We don't close the child's stdio here. The io-backend
+   * should notice EOF anyway, and the client should send EOF when it
+   * receives news of the process's death, unless it really wants to
+   * talk to any live grand children processes. */
 
   /* We close when we have both sent and received eof. */
   channel->flags |= CHANNEL_CLOSE_AT_EOF;
@@ -589,8 +593,8 @@ spawn_process(struct server_session *session,
 	if (child)
 	  { /* Parent */
 	    struct ssh_channel *channel = &session->super;
-	    debug("Parent process\n");
-
+	    trace("spawn_process: Parent process\n");
+	    
 	    session->process = child;
 
 	    /* Close the child's fd:s */
@@ -641,6 +645,7 @@ spawn_process(struct server_session *session,
 	     * cleaned up if the channel or connection dies. */
 	    REMEMBER_RESOURCE
 	      (channel->resources, child);
+
 	    /* FIXME: How to do this properly if in and out may use the
 	     * same fd? */
 	    REMEMBER_RESOURCE
@@ -655,9 +660,18 @@ spawn_process(struct server_session *session,
 	  }
 	else
 	  { /* Child */
-	    debug("spawn_process: Child process\n");
+	    trace("spawn_process: Child process\n");
 	    assert(getuid() == session->user->uid);
-	    
+
+#if 0
+	    /* Debug timing problems */
+	    if (sleep(5))
+	      {
+		trace("server_session.c: sleep interrupted\n");
+
+		sleep(5);
+	      }
+#endif    
 	    if (!USER_CHDIR_HOME(session->user))
 	      {
 		werror("Could not change to home (or root) directory!\n");
