@@ -2,7 +2,7 @@
  *
  * An implementation of Ron Rivest's S-expressions, used in spki.
  *
- * $Id: sexp.c,v 1.26 2000/05/01 20:21:03 nisse Exp $ */
+ * $Id: sexp.c,v 1.27 2000/05/06 19:26:17 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -940,7 +940,7 @@ sexp_output_options[] =
 {
   { NULL, 0, NULL, 0, "Valid sexp-formats are transport, canonical, "
     "advanced and international.", 0 },
-  { "output-format", 'o', "format", 0,
+  { "output-format", 'f', "format", 0,
     "Variant of the s-expression syntax to generate.", 0},
   { NULL, 0, NULL, 0, NULL, 0 }
 };
@@ -952,7 +952,7 @@ sexp_argp_parser(int key, char *arg, struct argp_state *state)
     {
     default:
       return ARGP_ERR_UNKNOWN;
-    case 'o':
+    case 'f':
     case 'i':
       {
 	int format = lookup_sexp_format(arg);
