@@ -1,6 +1,6 @@
 /* userauth.h
  *
- * $Id: userauth.h,v 1.21 2000/04/02 18:55:27 nisse Exp $
+ * $Id: userauth.h,v 1.23 2000/04/21 21:45:31 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -27,8 +27,9 @@
 
 #include "lsh.h"
 #include "exception.h"
+#include "resource.h"
 
-/* For pid_t and uid_t */
+/* For uid_t */
 #include <unistd.h>
 
 /* Forward declaration */
@@ -83,7 +84,10 @@ make_userauth_special_exception(struct lsh_string *reply,
        ; an object containing the stdin file objects and perhaps some
        ; other info.
 
-       (fork_process method int "pid_t *")
+       ; The tty argument is for utmp/wtmp logging
+       (fork_process method int "struct resource **child"
+                     "struct reap *reaper" "struct exit_callback *c"
+                     "struct address_info * peer" "struct lsh_string *tty")
 
        ; This modifies the argv vector, in particular its first
        ; element. So the vector must have at least two elements,
@@ -98,7 +102,8 @@ make_userauth_special_exception(struct lsh_string *reply,
 #define USER_VERIFY_PASSWORD(u, p, f) ((u)->verify_password((u), (p), (f)))
 #define USER_FILE_EXISTS(u, n, f) ((u)->file_exists((u), (n), (f)))
 #define USER_CHDIR_HOME(u) ((u)->chdir_home((u)))
-#define USER_FORK(u, c) ((u)->fork_process((u), (c)))
+#define USER_FORK(u, c, r, e, p, t) \
+  ((u)->fork_process((u), (c), (r), (e), (p), (t)))
 #define USER_EXEC(u, m, a, l, e) ((u)->exec_shell((u), (m), (a), (l), (e)))
 
 #endif /* LSH_USERAUTH_H_INCLUDED */
